# magoplotlib

Attentive External Library of [matplotlib](https://matplotlib.org/stable/index.html)

## Features

- plotting timestamp on a Figure.

![timestamp example](images/add_timestamp.png)

- plotting message on an Axes.

![message example](images/add_message.png)

## Requirements

- matplotlib

## Installation

```
pip install magoplotlib
```

## Usage

```python
from magoplotlib import add_timestamp

add_timestamp(fig)
```
